Skip to contents

Performs Hierarchical Clustering on a distance matrix (i.e. calculated with vcf2dist or fasta2dist) and generates a phylogenetic tree (complete linkage by default; single, complete, and average linkage are supported by the Java backend).

Usage

dist2tree(inputDist, verbose = FALSE)

Arguments

inputDist

Input distances file location (generated with vcf2dist or fasta2dist). File can be gzip compressed. Or a dist distances object.

verbose

Logical. If TRUE, enables verbose output from the Java backend.

Value

A character vector of the generated phylogenetic tree in Newick format.

References

Java implementation: https://github.com/gkanogiannis/BioInfoJava-Utils

Author

Anestis Gkanogiannis, anestis@gkanogiannis.com

Examples

my.tree <- dist2tree(
    inputDist =
    system.file("extdata", "samples.vcf.dist.gz", package = "fastreeR"),
    verbose = TRUE
)